/*
 * BetterBoard.java
 * Part of the Scribble problem set.
 *
 * Developed for "Rethinking CS101", a project of Lynn Andrea Stein's AP Group.
 * For more information, see http://www.ai.mit.edu/projects/cs101, the
 * CS101 homepage or email las@ai.mit.edu.
 *
 * Copyright (C) 1998 Massachusetts Institute of Technology.
 * Please do not redistribute without obtaining permission.
 */

package scribble;

import java.awt.event.*;
import java.awt.*;
import cs101.util.Coerce;

/**
 * BetterBoard connects the Whiteboard's clear and color selector GUI
 * elements to the ScribbleCanvas.  As opposed to Whiteboard, the
 * clear button and the color selector actually work as you might
 * expect.
 *
 * <P>Copyright (c) 1998 Massachusetts Institute of Technology
 *
 * @author Lynn Andrea Stein, las@ai.mit.edu
 * @author Todd C. Parnell, tparnell@ai.mit.edu
 * @version $Id: BetterBoard.java,v 1.4 2003/03/28 16:55:04 gus Exp $
 */
public class BetterBoard extends Whiteboard {
    
    /** Constructs a BetterBoard with a new SmartCanvas. */
    public BetterBoard() {
        this(new ScribbleCanvas());
    }
    
    /**
     * Constructs a BetterBoard with with given SmartCanvas.  Connects
     * the color selector and clear buttons to the SmartCanvas.
     */
    public BetterBoard(ScribbleCanvas myScribbleCanvas) {
        super(myScribbleCanvas);
        
        this.clearButton.addActionListener(new ActionListener() {
            public void actionPerformed(ActionEvent ae) {
                ((ScribbleCanvas)drawingArea).clearLines();
            }
        });
        this.colorChoice.addItemListener(new ItemListener() {
            public void itemStateChanged(ItemEvent ie) {
                ((ScribbleCanvas)drawingArea).setColor(Coerce.stringToColor
                (colorChoice.getSelectedItem()));
            }
        });
    }
}

/*
 * $Log: BetterBoard.java,v $
 * Revision 1.4  2003/03/28 16:55:04  gus
 * new name for Coerce method
 *
 * Revision 1.3  2003/02/26 22:14:05  gus
 * Reformat
 *
 * Revision 1.2  2003/02/26 22:12:02  gus
 * Made the import statements specific rather than using *'s
 *
 * Revision 1.1.1.1  2002/06/05 21:56:35  root
 * CS101 comes to Olin finally.
 *
 * Revision 1.1  2000/05/06 22:30:57  mharder
 * Moved to scribble subdirectory.
 *
 * Revision 1.5  1998/07/24 16:44:50  tparnell
 * Placate new javadoc behavior
 *
 * Revision 1.4  1998/07/21 14:09:03  tparnell
 * minor bugfixes necessary b/c 1.2 complier is more picky
 *
 * Revision 1.3  1998/07/20 18:55:31  tparnell
 * Added javadoc and logging.  Minor code mods for greater consistency
 * between files.
 *
 */
