/*
 * ScribbleData.java
 * Part of the Scribble problem set.
 *
 * Developed for "Rethinking CS101", a project of Lynn Andrea Stein's AP Group.
 * For more information, see http://www.ai.mit.edu/projects/cs101, the
 * CS101 homepage or email las@ai.mit.edu.
 *
 * Copyright (C) 1998 Massachusetts Institute of Technology.
 * Please do not redistribute without obtaining permission.
 */

package scribble;

import java.awt.*;
import java.util.*;
import cs101.awt.Line;

/**
 * ScribbleData is a repository of lines for use with a SmartCanvas.
 * It has methods to add and clear lines, as well as paint on a given
 * Graphics context.
 *
 * <P>Copyright (c) 1998 Massachusetts Institute of Technology
 *
 * @author Lynn Andrea Stein, las@ai.mit.edu
 * @author Todd C. Parnell, tparnell@ai.mit.edu
 * @version $Id: ScribbleData.java,v 1.1.1.1 2002/06/05 21:56:35 root Exp $
 */
public class ScribbleData {

  /** The Component whose lines we're storing. */
  private Component gui;
  /** Where we store the lines. */
  private Vector lines = new Vector(100, 100);

  /** Initilizes an empty ScribbleData. */
  public ScribbleData() {
  }
			  
  /** Initilizes an empty ScribbleData. */
  public ScribbleData(Component gui) {
    this.gui = gui;
  }

  /** Sets the Component we paint on. */
  public void setGUI(Component gui) {
    this.gui = gui;
  }

  /** Paints all lines on this onto g. */
  protected void paintLines (Graphics g) {
    for (int i = 0; i < lines.size(); i++) {
      ((Line)lines.elementAt(i)).drawOn(g);
    }
  }

  /** Stores a new line into this. */
  public synchronized void addLine (Line newLine) {
    lines.addElement(newLine);
    if (this.gui != null) {
      newLine.drawOn(this.gui.getGraphics());
    }
  }

  /** Clears all Lines from this. */
  public synchronized void clearLines() {
    lines.removeAllElements();
    gui.repaint();
  }
}

/*
 * $Log: ScribbleData.java,v $
 * Revision 1.1.1.1  2002/06/05 21:56:35  root
 * CS101 comes to Olin finally.
 *
 * Revision 1.1  2000/05/06 22:30:58  mharder
 * Moved to scribble subdirectory.
 *
 * Revision 1.4  1998/07/24 16:44:52  tparnell
 * Placate new javadoc behavior
 *
 * Revision 1.3  1998/07/22 17:59:34  tparnell
 * modifications to reflect new cs101.* package structure
 *
 * Revision 1.2  1998/07/20 18:55:33  tparnell
 * Added javadoc and logging.  Minor code mods for greater consistency
 * between files.
 *
 */



