/*
 * SmartCanvas.java
 * Part of the Scribble problem set.
 *
 * Developed for "Rethinking CS101", a project of Lynn Andrea Stein's AP Group.
 * For more information, see http://www.ai.mit.edu/projects/cs101, the
 * CS101 homepage or email las@ai.mit.edu.
 *
 * Copyright (C) 1998 Massachusetts Institute of Technology.
 * Please do not redistribute without obtaining permission.
 */

package scribble;

import java.awt.*;

/**
 * GUI component corresponding to the drawing space.  As implemented,
 * it doesn't do anything when you click on it, ie., it has no
 * facility for handling mouse events.
 *
 * <P>Copyright (c) 1998 Massachusetts Institute of Technology
 *
 * @author Lynn Andrea Stein, las@ai.mit.edu
 * @author Todd C. Parnell, tparnell@ai.mit.edu
 * @version $Id: SmartCanvas.java,v 1.1.1.1 2002/06/05 21:56:35 root Exp $
 */
public class SmartCanvas extends Canvas {
  /** holds and paints the lines */
  protected ScribbleData repository;

  private static final int PREFERRED_WIDTH = 300,
    PREFERRED_HEIGHT = 200;

  /**
   * Creates a new SmartCanvas.
   */
  public SmartCanvas() {
    this (new ScribbleData());
  }

  /**
   * Creates a new SmartCanvas with associated ScribbleData. 
   */
  public SmartCanvas(ScribbleData repository) {
    this.repository = repository;
    this.repository.setGUI(this);
    this.setSize(SmartCanvas.PREFERRED_WIDTH,
		 SmartCanvas.PREFERRED_HEIGHT);
  }

  /** Paints all Lines onto g. */
  public void paint (Graphics g) {
    this.repository.paintLines(g);
  }
}

/*
 * $Log: SmartCanvas.java,v $
 * Revision 1.1.1.1  2002/06/05 21:56:35  root
 * CS101 comes to Olin finally.
 *
 * Revision 1.1  2000/05/06 22:30:58  mharder
 * Moved to scribble subdirectory.
 *
 * Revision 1.4  1998/07/24 16:44:53  tparnell
 * Placate new javadoc behavior
 *
 * Revision 1.3  1998/07/21 19:06:14  tparnell
 * added more javadoc
 *
 * Revision 1.2  1998/07/20 18:55:33  tparnell
 * Added javadoc and logging.  Minor code mods for greater consistency
 * between files.
 *
 */















