/*
 * Whiteboard.java
 * Part of the Scribble problem set.
 *
 * Developed for "Rethinking CS101", a project of Lynn Andrea Stein's AP Group.
 * For more information, see http://www.ai.mit.edu/projects/cs101, the
 * CS101 homepage or email las@ai.mit.edu.
 *
 * Copyright (C) 1998 Massachusetts Institute of Technology.
 * Please do not redistribute without obtaining permission.
 */

package scribble;

import java.awt.event.*;
import java.awt.*;

/**
 * Whiteboard is the base Frame object.  It sets up the color selector
 * and clear button, but does not connect them to it's SmartCanvas. 
 *
 * <P>Copyright (c) 1998 Massachusetts Institute of Technology
 *
 * @author Lynn Andrea Stein, las@ai.mit.edu
 * @author Todd C. Parnell, tparnell@ai.mit.edu
 * @version $Id: Whiteboard.java,v 1.1.1.1 2002/06/05 21:56:35 root Exp $
 *
 * @see SmartCanvas
 */
public class Whiteboard extends Frame {
  /** the Canvas users draw on */
  protected SmartCanvas drawingArea;
  protected Button clearButton;
  /** drop down color list */
  protected Choice colorChoice;
    
  /** Constructs a Whiteboard with a new SmartCanvas. */
  public Whiteboard() {
    this(new SmartCanvas());
  }

  /** 
   * Constructs a Whiteboard with the given SmartCanvas.  Sets up the
   * color selector and clear buttons.
   */
  public Whiteboard(SmartCanvas drawingArea) {
    this.drawingArea = drawingArea;
    this.clearButton = new Button ("Clear");
	
    this.colorChoice = new Choice ();
    this.colorChoice.addItem("Black");
    this.colorChoice.addItem("Red");
    this.colorChoice.addItem("Green");
    this.colorChoice.addItem("Blue");
    this.colorChoice.addItem("Yellow");
    this.colorChoice.addItem("Cyan");
    this.colorChoice.addItem("Magenta");
    this.colorChoice.addItem("White");
    this.colorChoice.addItem("Orange");
    this.colorChoice.addItem("Pink");

    this.colorChoice.select("Black");

    this.setTitle("CS101 Scribbler");

    this.setLayout(new BorderLayout(10, 10)); 

    // all control widgets go in buttonArea (to simplify layout)
    Panel buttonArea = new Panel();
    buttonArea.setLayout(new FlowLayout());
    buttonArea.add(this.colorChoice);
    buttonArea.add(this.clearButton);

    this.add("North", buttonArea);
    this.add("Center", this.drawingArea);

    this.addWindowListener(new WindowAdapter() {
      public void windowClosing(WindowEvent we) {
	Whiteboard.this.setVisible(false);
	Whiteboard.this.dispose();
	System.exit(0);
      } 
    });

    this.pack();
    this.show();
  }    
}
    
/*
 * $Log: Whiteboard.java,v $
 * Revision 1.1.1.1  2002/06/05 21:56:35  root
 * CS101 comes to Olin finally.
 *
 * Revision 1.1  2000/05/06 22:30:58  mharder
 * Moved to scribble subdirectory.
 *
 * Revision 1.5  1998/07/24 16:44:53  tparnell
 * Placate new javadoc behavior
 *
 * Revision 1.4  1998/07/21 19:05:50  tparnell
 * added more javadoc
 *
 * Revision 1.3  1998/07/21 14:09:04  tparnell
 * minor bugfixes necessary b/c 1.2 complier is more picky
 *
 * Revision 1.2  1998/07/20 18:55:33  tparnell
 * Added javadoc and logging.  Minor code mods for greater consistency
 * between files.
 *
 */








